LocationPermissionStatus enum
Location permission status
- Inheritance
- Available extensions
Values
- denied → const LocationPermissionStatus
-
Permission has been denied
- deniedForever → const LocationPermissionStatus
-
Permission has been denied forever (user must enable from settings)
- whileInUse → const LocationPermissionStatus
-
Permission has been granted for foreground only
- always → const LocationPermissionStatus
-
Permission has been granted for both foreground and background
- notDetermined → const LocationPermissionStatus
-
Permission status is not determined yet
Properties
- canRequest → bool
-
Available on LocationPermissionStatus, provided by the LocationPermissionStatusExtension extension
Whether permission can be requestedno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isDenied → bool
-
Available on LocationPermissionStatus, provided by the LocationPermissionStatusExtension extension
Whether permission is deniedno setter - isGranted → bool
-
Available on LocationPermissionStatus, provided by the LocationPermissionStatusExtension extension
Whether permission is grantedno setter - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
LocationPermissionStatus> - A constant List of the values in this enum, in order of their declaration.